Please use the following to cite the latest version of the Nashpy library::

```
@misc{nashpyproject,
  author       = {{ {The Nashpy project developers} }},
  title        = {Nashpy: <RELEASE TITLE>},
  month        = <MONTH>,
  year         = <YEAR>,
  doi          = {<DOI INFORMATION>},
  url          = {http://dx.doi.org/10.5281/zenodo.<DOI NUMBER>}
}
```

To check the details (RELEASE TITLE, DOI INFORMATION and DOI NUMBER) please view
the Zenodo page for the project. Click on the badge/link below:

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.164954.svg)](https://doi.org/10.5281/zenodo.164954)
